Features
--------

    * Support for PyQt5, PyQt6, PySide2 and PySide6.

    * Multiple platforms supported, including Linux, Mac & Windows.

    * No in-depth knowledge is needed on multithreading to get started.

    * Different modes of data-acquisition are available:
        - periodic to a fixed clock
        - synchronized across multiple devices
        - aperiodic -- triggered by specific events
        - continuous -- for high-speed buffered applications